aboutsummaryrefslogtreecommitdiff
path: root/engine/handlers
diff options
context:
space:
mode:
Diffstat (limited to 'engine/handlers')
-rw-r--r--engine/handlers/pagehandler.php5
1 files changed, 2 insertions, 3 deletions
diff --git a/engine/handlers/pagehandler.php b/engine/handlers/pagehandler.php
index e824b5232..7d293c3e4 100644
--- a/engine/handlers/pagehandler.php
+++ b/engine/handlers/pagehandler.php
@@ -9,8 +9,7 @@
*
* {@link page_handler()} explodes the pages string by / and sends it to
* the page handler function as registered by {@link register_page_handler()}.
* If a valid page handler isn't found, the user will be forwarded to the site
* front page.
*
* @package Elgg.Core
* @subpackage PageHandler
@@ -23,5 +22,5 @@ $handler = get_input('handler');
$page = get_input('page');
if (!page_handler($handler, $page)) {
- forward();
+ forward('', '404');
} \ No newline at end of file
@@ -9,8 +9,7 @@
* {@link page_handler()} explodes the pages string by / and sends it to
* the page handler function as registered by {@link register_page_handler()}.
- * If a valid page handler isn't found, the user will be forwarded to the site
- * front page.
+ * If a valid page handler isn't found, plugins have a chance to provide a 404.
*
* @package Elgg.Core